Actions, Resources, and Condition Keys for AWS IoT Analytics - AWS Identity and Access Management
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.

# Actions, Resources, and Condition Keys for AWS IoT Analytics

AWS IoT Analytics (service prefix: `iotanalytics` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS IoT Analytics
- Resource Types Defined by AWS IoT Analytics
- Condition Keys for AWS IoT Analytics

## Actions Defined by AWS IoT Analytics

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
BatchPutMessage | Puts a batch of messages into the specified channel. | Write | channel* |  |
CancelPipelineReprocessing | Cancels reprocessing for the specified pipeline. | Write | pipeline* |  |
CreateChannel | Creates a channel. | Write | channel* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateDataset | Creates a dataset. | Write | dataset* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateDatasetContent | Generates content of the specified dataset (by executing the dataset actions). | Write | dataset* |  |
CreateDatastore | Creates a datastore. | Write | datastore* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreatePipeline | Creates a pipeline. | Write | pipeline* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteChannel | Deletes the specified channel. | Write | channel* |  |
DeleteDataset | Deletes the specified dataset. | Write | dataset* |  |
DeleteDatasetContent | Deletes the content of the specified dataset. | Write | dataset* |  |
DeleteDatastore | Deletes the specified datastore. | Write | datastore* |  |
DeletePipeline | Deletes the specified pipeline. | Write | pipeline* |  |
DescribeChannel | Describes the specified channel. | Read | channel* |  |
DescribeDataset | Describes the specified dataset. | Read | dataset* |  |
DescribeDatastore | Describes the specified datastore. | Read | datastore* |  |
DescribeLoggingOptions | Describes logging options for the the account. | Read |  |  |
DescribePipeline | Describes the specified pipeline. | Read | pipeline* |  |
GetDatasetContent | Gets the content of the specified dataset. | Read | dataset* |  |
ListChannels | Lists the channels for the account. | List |  |  |
ListDatasets | Lists the datasets for the account. | List |  |  |
ListDatastores | Lists the datastores for the account. | List |  |  |
ListPipelines | Lists the pipelines for the account. | List |  |  |
ListTagsForResource | Lists the tags (metadata) which you have assigned to the resource. | Read | channel |  |
dataset |  |
datastore |  |
pipeline |  |
PutLoggingOptions | Puts logging options for the the account. | Write |  |  |
RunPipelineActivity | Runs the specified pipeline activity. | Read |  |  |
SampleChannelData | Samples the specified channel's data. | Read | channel* |  |
StartPipelineReprocessing | Starts reprocessing for the specified pipeline. | Write | pipeline* |  |
TagResource | Adds to or modifies the tags of the given resource. Tags are metadata which can be used to manage a resource. | Tagging | channel |  |
dataset |  |
datastore |  |
pipeline |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Removes the given tags (metadata) from the resource. | Tagging | channel |  |
dataset |  |
datastore |  |
pipeline |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UpdateChannel | Updates the specified channel. | Write | channel* |  |
UpdateDataset | Updates the specified dataset. | Write | dataset* |  |
UpdateDatastore | Updates the specified datastore. | Write | datastore* |  |
UpdatePipeline | Updates the specified pipeline. | Write | pipeline* |  |

## Resource Types Defined by AWS IoT Analytics

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
channel | `arn:$ { Partition}:iotanalytics:$ { Region}:$ { Account}:channel/$ { ChannelName}` | aws:RequestTag/${TagKey} aws:TagKeys iotanalytics:ResourceTag/${TagKey}
dataset | `arn:$ { Partition}:iotanalytics:$ { Region}:$ { Account}:dataset/$ { DatasetName}` | aws:RequestTag/${TagKey} aws:TagKeys iotanalytics:ResourceTag/${TagKey}
datastore | `arn:$ { Partition}:iotanalytics:$ { Region}:$ { Account}:datastore/$ { DatastoreName}` | aws:RequestTag/${TagKey} aws:TagKeys iotanalytics:ResourceTag/${TagKey}
pipeline | `arn:$ { Partition}:iotanalytics:$ { Region}:$ { Account}:pipeline/$ { PipelineName}` | aws:RequestTag/${TagKey} aws:TagKeys iotanalytics:ResourceTag/${TagKey}

## Condition Keys for AWS IoT Analytics

AWS IoT Analytics defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/$ { TagKey} | A tag key that is present in the request that the user makes to IoT Analytics. | String
aws:TagKeys | The list of all the tag key names associated with the IoT Analytics resource in the request. | String
iotanalytics:ResourceTag/$ { TagKey} | The preface string for a tag key and value pair attached to an IoT Analytics resource. | String